from src.matpak.types import mat_t, vec_t

def imp_mat_file(file: str, sep: str = ',') -> mat_t:
    """
    :param file: path to matrix file. each line in file represents a
    :param sep: file's elements separator char; by default, it is comma ','.

    :return: mat_t
    """
    pass


def imp_vec_file(file: str, sep: str = ',') -> vec_t:
    """
    :param file: path to vector file. each element in file represents a vector element.
    :param sep: file's elements separator char; by default, it is comma ','.

    :return: vec_t
    """
    pass
